#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Oct 27 11:05:30 2020

@author: ageiges
"""

from . import  for_datatables 
#from . import install_support

from . import pandas
from . import excel
from . import xarray
from . import matplotlib
#from . import pyam

#from . import py_magicc_tools


